@@ -61,13 +61,17 @@ class PostLayout(object):
       self.activateappendix()
     if layout.type in PostLayout.unique:
       number = self.generator.generateunique(layout.type)
+      text = TranslationConfig.constants[layout.type] + ' ' + number + u'. '
     elif layout.type in PostLayout.ordered:
       level = PostLayout.ordered.index(layout.type)
       number = self.generator.generate(level)
+      text = number + u' '
     else:
       return layout
     layout.number = number
-    layout.contents.insert(0, Constant(number + u' '))
+    anchor = 'toc-' + layout.type + '-' + number
+    link = Link().complete(text, anchor=anchor, type='toc')
+    layout.contents.insert(0, link)
     return layout
 
   def containsappendix(self, layout):
