@@ -46,8 +46,10 @@ class Options(object):
   title = None
   directory = None
   destdirectory = None
-  toc = False
+  toc = None
   forceformat = None
+  lyxformat = False
+  target = None
   branches = dict()
 
   def parseoptions(self, args):
@@ -65,6 +67,8 @@ class Options(object):
       self.showhardversion()
     if Options.versiondate:
       self.showversiondate()
+    if Options.lyxformat:
+      self.showlyxformat()
     # set in Trace if necessary
     for param in dir(Options):
       if hasattr(Trace, param + 'mode'):
@@ -85,6 +89,9 @@ class Options(object):
     Trace.error('    --html: output HTML 4.0 instead of the default XHTML')
     Trace.error('    --unicode: full Unicode output')
     Trace.error('    --forceformat ".extension": force image output format')
+    Trace.error('    --lyxformat: return the highest LyX version that can be converted')
+    Trace.error('    --toc "original.html": create a TOC with links to the original')
+    Trace.error('    --target "frame": make all links point to the given frame')
     exit()
 
   def showversion(self):
@@ -104,6 +111,11 @@ class Options(object):
     Trace.message(GeneralConfig.version['date'])
     exit()
 
+  def showlyxformat(self):
+    "Return just the lyxformat parameter"
+    Trace.message(GeneralConfig.version['lyxformat'])
+    exit()
+
 class BranchOptions(object):
   "A set of options for a branch"
 
